#-------------------------------------------------------- 
# Script to extract/format WMQI user trace data
#--------------------------------------------------------
# set -o xtrace

#------------------------------------------
# Set variables
#------------------------------------------
version=1.10
mqsi_trace_file_xml=mqsitrac.xml
mqsi_trace_file_txt=mqsitrac.txt
mqsi_trace_file_tab=mqsitrac.tab
temp_file=mqsitemp.txt
out_lrecl=100


echo
echo "===================================================================="
echo "$0    Version $version"      
echo "===================================================================="

if [[ -z $2 ]]; then
   #-----------------------------------------------
   # Show help if insufficient parameters specified 
   #-----------------------------------------------
   echo
   echo "  Usage "
   echo "      $0   broker_name  execution_group"
   echo
else
   echo
   echo "-------------------Delete previous trace data------------------------------"
   echo > $mqsi_trace_file_xml
   echo > $mqsi_trace_file_txt
   echo > $mqsi_trace_file_tab

   echo
   echo "-------------------Read user trace data------------------------------------"
   mqsireadlog $1 -u -e $2 -f -o $mqsi_trace_file_xml

   echo
   echo "-------------------Change locale for language selection--------------------"
   LANGOLD=${LANG}

   if [[ -z $LANG ]]; then
     LANG=C
   fi
   NEWLOCALE=$LANG
   until [[ -z $NEWLOCALE ]]; do
      echo '*************************************'
      echo '* Current locale is '`locale | grep LC_MESSAGES`'.' | sed 's/LC_MESSAGES=//'
      echo '*************************************'
      echo
      echo '(Installed locale : '`locale -a`')'
      echo
      echo 'Input temporary locale if you want to change language of trace data.  Press ENTER to proceed.'
      echo
      read NEWLOCALE
      if [[ -n $NEWLOCALE ]]; then
        export LANG=$NEWLOCALE
      fi
   done

   echo "-------------------Format user trace--------------------------------------"
   mqsiformatlog -i $mqsi_trace_file_xml -o $temp_file
   ./mqsitrcf $out_lrecl < $temp_file > $mqsi_trace_file_txt
   ./mqsitrcf -tab       < $temp_file > $mqsi_trace_file_tab
   rm $temp_file

   echo 
   echo 'Generated Trace files :'
   echo '   XML format  ==> '$mqsi_trace_file_xml
   echo '   Text format ==> '$mqsi_trace_file_txt
   echo '   Tab format  ==> '$mqsi_trace_file_tab 
   echo

   #------------------------------------------
   # Restore locale 
   #------------------------------------------
   export LANG=${LANGOLD}

fi

